@@ -1,4 +1,4 @@
-"""jc - JSON CLI output utility `crontab -l` command output and crontab
+"""jc - JSON Convert `crontab -l` command output and crontab
 file parser
 
 Supports `crontab -l` command output and crontab files.
