@@ -1,4 +1,4 @@
-"""jc - JSON CLI output utility `du` command output parser
+"""jc - JSON Convert `du` command output parser
 
 Usage (cli):
 
