@@ -1,4 +1,4 @@
-"""jc - JSON CLI output utility `finger` command output parser
+"""jc - JSON Convert `finger` command output parser
 
 Supports `-s` output option. Does not support the `-l` detail option.
 
