@@ -1,4 +1,4 @@
-"""jc - JSON CLI output utility `free` command output parser
+"""jc - JSON Convert `free` command output parser
 
 Usage (cli):
 
