@@ -1,4 +1,4 @@
-"""jc - JSON CLI output utility `hash sum` command output parser
+"""jc - JSON Convert `hash sum` command output parser
 
 This parser works with the following hash calculation utilities:
 - `md5`
