@@ -1,4 +1,4 @@
-"""jc - JSON CLI output utility `ifconfig` command output parser
+"""jc - JSON Convert `ifconfig` command output parser
 
 Note: No `ifconfig` options are supported.
 
