@@ -1,4 +1,4 @@
-"""jc - JSON CLI output utility `iostat` command output streaming parser
+"""jc - JSON Convert `iostat` command output streaming parser
 
 > This streaming parser outputs JSON Lines
 
