@@ -1,4 +1,4 @@
-"""jc - JSON CLI output utility `ls` and `vdir` command output parser
+"""jc - JSON Convert `ls` and `vdir` command output parser
 
 Options supported:
 - `lbaR1`
