@@ -1,4 +1,4 @@
-"""jc - JSON CLI output utility `lsusb` command output parser
+"""jc - JSON Convert `lsusb` command output parser
 
 Supports the `-v` option or no options.
 
