@@ -1,4 +1,4 @@
-"""jc - JSON CLI output utility `mount` command output parser
+"""jc - JSON Convert `mount` command output parser
 
 Usage (cli):
 
