@@ -1,4 +1,4 @@
-"""jc - JSON CLI output utility `ping` command output parser
+"""jc - JSON Convert `ping` command output parser
 
 Supports `ping` and `ping6` output.
 
