@@ -1,4 +1,4 @@
-"""jc - JSON CLI output utility `rpm -qi` command output parser
+"""jc - JSON Convert `rpm -qi` command output parser
 
 Works with `rpm -qi [package]` or `rpm -qia`.
 
