@@ -1,4 +1,4 @@
-"""jc - JSON CLI output utility `systemctl` command output parser
+"""jc - JSON Convert `systemctl` command output parser
 
 Usage (cli):
 
