@@ -1,4 +1,4 @@
-"""jc - JSON CLI output utility `uname -a` command output parser
+"""jc - JSON Convert `uname -a` command output parser
 
 Note: Must use `uname -a`
 
