@@ -1,4 +1,4 @@
-"""jc - JSON CLI output utility `XML` file parser
+"""jc - JSON Convert `XML` file parser
 
 Usage (cli):
 
