@@ -1,4 +1,4 @@
-"""jc - JSON CLI output utility `xrandr` command output parser
+"""jc - JSON Convert `xrandr` command output parser
 
 Usage (cli):
 
@@ -31,18 +31,21 @@ Schema:
           "maximum_width":                     integer,
           "maximum_height":                    integer,
           "associated_device": {
-          "associated_modes": [
-            {
-            "resolution_width":                integer,
-            "resolution_height":               integer,
-            "is_high_resolution":              boolean,
-            "frequencies": [
+            "associated_modes": [
               {
-              "frequency":                     float,
-              "is_current":                    boolean,
-              "is_preferred":                  boolean
+                "resolution_width":            integer,
+                "resolution_height":           integer,
+                "is_high_resolution":          boolean,
+                "frequencies": [
+                  {
+                    "frequency":               float,
+                    "is_current":              boolean,
+                    "is_preferred":            boolean
+                  }
+                ]
               }
-          ],
+            ]
+          },
           "is_connected":                      boolean,
           "is_primary":                        boolean,
           "device_name":                       string,
@@ -52,7 +55,6 @@ Schema:
           "offset_height":                     integer,
           "dimension_width":                   integer,
           "dimension_height":                  integer
-          }
         }
       ],
       "unassociated_devices": [
@@ -137,7 +139,6 @@ Examples:
 """
 import re
 from typing import Dict, List, Optional, Union
-
 import jc.utils
 
 
@@ -287,7 +288,7 @@ def _parse_device(next_lines: List[str], quiet: bool = False) -> Optional[Device
                     device[k] = int(v)
             except ValueError and not quiet:
                 jc.utils.warning_message(
-                    [f"Error: {next_line} : {k} - {v} is not int-able"]
+                    [f"{next_line} : {k} - {v} is not int-able"]
                 )
 
     while next_lines:
